<?php
/*
* Smarty plugin
* -------------------------------------------------------------
* Purpose: weight converter, kg to other unit
* Usage:    In the template, use
            {$weight|weight_format}    =>    5.00 kg
            or
            {$weight|weight_format:"pound"}    =>    11.02 pound
            or
            {$weight|weight_format:"oz":4}    =>    176.3698 oz           
            or
            {$weight|weight_format:"g":0:".":""}    =>    5000 g
* Params:    
            int        size            the weight in kg
            string    format            the format, the output shall be: kg, g, t, oz, pound, st
            int        precision        the rounding precision
            string    dec_point        the decimal separator
            string    thousands_sep    the thousands separator    
* -------------------------------------------------------------
*/
function smarty_modifier_weight_format($size,$format = 'kg',$precision = 2, $dec_point = ".", $thousands_sep = ",")
{

    static $sizes = array();
    
    if(!count($sizes)) {
        $b = 1024;
        $sizes["kg"]        =    1;
        $sizes["g"]    =    1000;               // gramm     
        $sizes["t"]    =    0.001;              // tonne
        $sizes["oz"]    =    35.273966;         // unze
        $sizes["pound"]    =    2.204623;       // pfund
        $sizes["st"]    =    0.157473;       // stones
        
        $sizes = array_reverse($sizes,true);
    }    
    

    foreach($sizes    AS    $unit => $multiplier) {
        if($unit == $format) {
            //~ return formatted size
            $weight = number_format($size * $multiplier,$precision,$dec_point,$thousands_sep);
            
            $weight_4 = number_format($size * $multiplier,4,$dec_point,$thousands_sep);
            if ((float)$weight<(float)$weight_4) {
                $weight = $weight_4;
                //$weight = rtrim($weight,"0");
            }
            return $weight ." ".$unit;  
                     
        } //~ end if
    } //~ end foreach
} //~ end function
?>